# Creating an Automation with a Webhook Action
### On this page
  * [Step 1: Create an Automation](https://help.sap.com/docs/leanix/ea/automations-webhooks#step-1:-create-an-automation)
  * [Step 2: Create a Webhook](https://help.sap.com/docs/leanix/ea/automations-webhooks#step-2:-create-a-webhook)
  * [Option 1: Create a Webhook in the Administration Area](https://help.sap.com/docs/leanix/ea/automations-webhooks#option-1:-create-a-webhook-in-the-administration-area)
  * [Option 2: Create a Webhook Subscription Through the API](https://help.sap.com/docs/leanix/ea/automations-webhooks#option-2:-create-a-webhook-subscription-through-the-api)


Send webhooks from automations to trigger external workflows.
You can create automations that send a webhook to a target URL, allowing you to trigger external workflows. For more information, see [Sending a Webhook from an Automation](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758d6af7a441014b829a7547e83bfd4__sending_a_webhook_from_an_automation).
